==> pyOCD-0.4.3.zip: pyOCD-0.4.3/pyOCD/target/target_max32600mbed.py <==
"""
 mbed CMSIS-DAP debugger
 Copyright (c) 2006-2013 ARM Limited

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
"""

from cortex_m import CortexM
from pyOCD.transport.cmsis_dap_core import PINS
import logging

class MAX32600MBED(CortexM):

    memoryMapXML =  """<?xml version="1.0"?>
<!DOCTYPE memory-map PUBLIC "+//IDN gnu.org//DTD GDB Memory Map V1.0//EN" "http://sourceware.org/gdb/gdb-memory-map.dtd">
<memory-map>
    <memory type="flash" start="0x0" length="0x40000"> <property name="blocksize">0x800</property></memory>
    <memory type="ram" start="0x20000000" length="0x8000"> </memory>
    <memory type="ram" start="0x40000000" length="0x100000"> </memory>
    <memory type="ram" start="0xe0000000" length="0x100000"> </memory>
</memory-map>
"""

    def __init__(self, transport):
        super(MAX32600MBED, self).__init__(transport)

    def readIDCode(self):
        """
        return the IDCODE of the core
        """
        if self.idcode == 0:
            self.idcode = self.protocol.jtagIDCode()
        return self.idcode

    def dsb(self):
        logging.info("Triggering Destructive Security Bypass...")

        self.protocol.vendor(1)

        # Reconnect debugger
        self.transport.init()

    def fge(self):
        logging.info("Triggering Factory Global Erase...")

        self.protocol.vendor(2)

        # Reconnect debugger
        self.transport.init()

==> pyOCD-0.6.0.zip: pyOCD-0.6.0/pyOCD/target/target_max32600mbed.py <==
"""
 mbed CMSIS-DAP debugger
 Copyright (c) 2006-2013 ARM Limited

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
"""

from cortex_m import CortexM
from .memory_map import (FlashRegion, RamRegion, MemoryMap)
from pyOCD.transport.cmsis_dap_core import PINS
import logging

class MAX32600MBED(CortexM):

    memoryMap = MemoryMap(
        FlashRegion(    start=0,           length=0x40000,      blocksize=0x800, isBootMemory=True),
        RamRegion(      start=0x20000000,  length=0x8000),
        RamRegion(      start=0x40000000,  length=0x100000),
        RamRegion(      start=0xe0000000,  length=0x100000)
        )

    def __init__(self, transport):
        super(MAX32600MBED, self).__init__(transport, self.memoryMap)

    def readIDCode(self):
        """
        return the IDCODE of the core
        """
        if self.idcode == 0:
            self.idcode = self.protocol.jtagIDCode()
        return self.idcode

    def dsb(self):
        logging.info("Triggering Destructive Security Bypass...")

        self.protocol.vendor(1)

        # Reconnect debugger
        self.transport.init()

    def fge(self):
        logging.info("Triggering Factory Global Erase...")

        self.protocol.vendor(2)

        # Reconnect debugger
        self.transport.init()
